@@ -1,7 +1,7 @@
-#' SMMT - The Swiss Municipality Merger Tool Maps Municipalities Over Time
+#' SMMT - The Swiss Municipal Data Merger Tool Maps Municipalities Over Time
 #' 
 #' In Switzerland, the landscape of municipalities is changing rapidly mainly
-#' due to mergers. The Swiss Municipality Merger Tool  automatically detects
+#' due to mergers. The Swiss Municipal Data Merger Tool automatically detects
 #' these mutations and maps municipalities of an old state to municipalities of
 #' a new state. This functionality is helpful when working with datasets that
 #' are based on different spatial references. The spatial reference in this
@@ -16,14 +16,16 @@
 #' @import XML
 #' @import dplyr
 #' @import tibble
+#' @importFrom curl curl_download
+#' @importFrom utils unzip
 #'   
 utils::globalVariables(c("admission_date", "state", "status",
 "abolition_date", "abolition_mode", "abolition_nr", "add_column", "admission_mode",
-"admission_nr", "bfs_nr_new", "bundle_id", "cantonAbbreviation",
+"admission_nr", "bfs_nr_new", "bfs_nr_old", "bundle_id", "cantonAbbreviation",
 "cantonDateOfChange", "districtHistId", "entry_mode", "hist_id",
 "historyMunicipalityId", "municipalityAbolitionDate",
 "municipalityAbolitionMode", "municipalityAbolitionNumber",
 "municipalityAdmissionDate", "municipalityAdmissionMode",
 "municipalityAdmissionNumber", "municipalityDateOfChange",
 "municipalityEntryMode", "municipalityId", "municipalityLongName",
-"municipalityShortName", "municipalityStatus"))
+"municipalityShortName", "municipalityStatus", "name_new", "name_old", "is_xml"))
